@@ -63,7 +63,7 @@ use version 0.77;
 use warnings;
 
 # ABSTRACT: Test your Dist::Zilla plugin
-our $VERSION = 'v0.4.3_03'; # TRIAL VERSION
+our $VERSION = 'v0.4.4'; # VERSION
 
 use Dist::Zilla::Tester::DieHard v0.6.0;    # `Survivor` should have `tempdir_obj` attribute.
 use File::Temp qw{ tempdir };
@@ -96,7 +96,7 @@ use Try::Tiny;
 #pod
 #pod =item C<1>
 #pod
-#pod Clean up temporary directory only if the test is passed.
+#pod Clean up temporary directory only if the test is passed (it is default).
 #pod
 #pod =item C<2>
 #pod
@@ -104,8 +104,6 @@ use Try::Tiny;
 #pod
 #pod =back
 #pod
-#pod Default value is C<1>.
-#pod
 #pod If temporary directory is going to remain, the test output will contain diagnostic message like
 #pod this one:
 #pod
@@ -113,6 +111,8 @@ use Try::Tiny;
 #pod
 #pod to help you identify the temporary directory created for the test.
 #pod
+#pod Note: Controlling temporary directory requires C<Dist::Zilla> 5.021 or newer.
+#pod
 #pod =cut
 
 our $Cleanup = 1;                       ## no critic ( ProhibitPackageVars )
@@ -643,8 +643,7 @@ Test::Dist::Zilla - Test your Dist::Zilla plugin
 
 =head1 VERSION
 
-Version v0.4.3_03, released on 2016-12-23 20:12 UTC.
-This is a B<trial release>.
+Version v0.4.4, released on 2016-12-28 19:48 UTC.
 
 =head1 SYNOPSIS
 
@@ -929,7 +928,7 @@ Never clean up temporary directory.
 
 =item C<1>
 
-Clean up temporary directory only if the test is passed.
+Clean up temporary directory only if the test is passed (it is default).
 
 =item C<2>
 
@@ -937,8 +936,6 @@ Always clean up temporary directory.
 
 =back
 
-Default value is C<1>.
-
 If temporary directory is going to remain, the test output will contain diagnostic message like
 this one:
 
@@ -946,6 +943,8 @@ this one:
 
 to help you identify the temporary directory created for the test.
 
+Note: Controlling temporary directory requires C<Dist::Zilla> 5.021 or newer.
+
 =head1 SEE ALSO
 
 =over 4
